//+------------------------------------------------------------------+
//|                                           RecentHighLowAlert.mq4 |
//|                                                    Andriy Moraru |
//|                                         http://www.earnforex.com |
//|            							                            2013 |
//+------------------------------------------------------------------+
#property copyright "www.EarnForex.com, 2013"
#property link      "http://www.earnforex.com"

/*
   Draws lines on the high/low of the recent N bars.
   Alerts when the Bid price of the current bar crosses previous high/low.
*/

#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1  DodgerBlue
#property indicator_color2  Yellow

#define HIGH 1
#define LOW 0

extern int N = 20;
extern bool SoundAlert = true;
extern bool PopupAlert = false;
extern bool EmailAlert = false;

double HighBuf[];
double LowBuf[];

datetime LastHighAlert = D'1970.01.01';
datetime LastLowAlert = D'1970.01.01';

//+------------------------------------------------------------------+
//| Called once on initialization.                                   |
//+------------------------------------------------------------------+
void init()
{       
   SetIndexStyle(0, DRAW_LINE, STYLE_SOLID, 1);
   SetIndexStyle(1, DRAW_LINE, STYLE_SOLID, 1);

   SetIndexLabel(0, "High");
   SetIndexLabel(1, "Low");

   SetIndexDrawBegin(0, N);
   SetIndexDrawBegin(1, N);

   SetIndexBuffer(0, HighBuf);
   SetIndexBuffer(1, LowBuf);
}

//+------------------------------------------------------------------+
//| Called every tick.                                               |
//+------------------------------------------------------------------+
int start() 
{
   int counted = IndicatorCounted();

   if (counted < 0) return(-1);

   if (counted > 0) counted--;
   
   int limit = Bars - counted;

   for (int i = 0; i < limit; i++)
   {
      HighBuf[i] = High[iHighest(NULL, 0, MODE_HIGH, N, i)];
      LowBuf[i] = Low[iLowest(NULL, 0, MODE_LOW, N, i)];
   }
   
   if ((Bid > HighBuf[1]) && (LastHighAlert != Time[0])) SendAlert(HIGH, HighBuf[1]);
   else if ((Bid < LowBuf[1]) && (LastLowAlert != Time[0])) SendAlert(LOW, LowBuf[1]);
   
   return(0);
}

//+------------------------------------------------------------------+
//| Issues alerts and remembers last sent alert time.                |
//+------------------------------------------------------------------+
void SendAlert(int direction, double price) 
{
   string alert = " Local ";
   string subject;
   
   if (direction == HIGH)
   {
      alert = alert + "high";
      subject = "High broken";
      LastHighAlert = Time[0];
   }
   else if (direction == LOW)
   {
      alert = alert + "low";
      subject = "Low broken";
      LastLowAlert = Time[0];
   }
   alert = alert + " broken at " + DoubleToStr(price, Digits) + ".";

   if (SoundAlert) PlaySound("alert.wav");
   if (PopupAlert) Alert(alert);
   if (EmailAlert) SendMail(subject, TimeToStr(TimeCurrent(), TIME_DATE|TIME_SECONDS) + alert);
}
//+------------------------------------------------------------------+

